@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -21,20 +21,14 @@
 
 import collections
 import hashlib
-import sys
 from abc import abstractmethod
 
 from nuitka import Options
 from nuitka.__past__ import getMetaClassBase, iterItems
-from nuitka.Builtins import (
-    builtin_anon_codes,
-    builtin_anon_values,
-    builtin_exception_values_list,
-)
+from nuitka.constants.Serialization import ConstantAccessor
 from nuitka.PythonVersions import python_version
 from nuitka.utils.InstanceCounters import counted_del, counted_init
 
-from .Namify import namifyConstant
 from .VariableDeclarations import VariableDeclaration, VariableStorage
 
 # Many methods won't use self, but it's the interface. pylint: disable=no-self-use
@@ -263,7 +257,9 @@ class TempMixin(object):
 
     def addCleanupTempName(self, tmp_name):
         assert tmp_name not in self.cleanup_names[-1], tmp_name
-        assert tmp_name.c_type != "void"
+        assert (
+            tmp_name.c_type != "nuitka_void" or tmp_name.code_name == "tmp_unused"
+        ), tmp_name
 
         self.cleanup_names[-1].append(tmp_name)
 
@@ -576,229 +572,8 @@ class PythonChildContextBase(PythonContextBase):
     def getFrameVariableCodeNames(self):
         return self.parent.getFrameVariableCodeNames()
 
-
-def _getConstantDefaultPopulation():
-    # Lots of cases, pylint: disable=too-many-branches
-
-    # Note: Can't work with set here, because we need to put in some values that
-    # cannot be hashed.
-
-    result = [
-        # Basic values that the helper code uses all the times.
-        (),
-        {},
-        "",
-        True,
-        False,
-        0,
-        1,
-        # Some math operations shortcut to these
-        0.0,
-        -0.0,
-        # For Python3 empty bytes, no effect for Python2, same as "", used for
-        # code objects.
-        b"",
-        # Python mechanics, used in various helpers.
-        "__module__",
-        "__class__",
-        "__name__",
-        "__package__",
-        "__metaclass__",
-        "__dict__",
-        "__doc__",
-        "__file__",
-        "__path__",
-        "__enter__",
-        "__exit__",
-        "__builtins__",
-        "__all__",
-        "__cmp__",
-        "__iter__",
-        # Nuitka specific
-        "__compiled__",
-        # Patched module name.
-        "inspect",
-        # Names of built-ins used in helper code.
-        "compile",
-        "range",
-        "open",
-        "sum",
-        "format",
-        "__import__",
-        "bytearray",
-        "staticmethod",
-        "classmethod",
-        # Arguments of __import__ built-in used in helper code.
-        "name",
-        "globals",
-        "locals",
-        "fromlist",
-        "level",
-        # Meta path based loader.
-        "read",
-        "rb",
-    ]
-
-    if python_version >= 300:
-        # For Python3 modules
-        result += ("__cached__", "__loader__")
-
-        # For Python3 print
-        result += ("print", "end", "file")
-
-        # For Python3 "bytes" built-in.
-        result.append("bytes")
-
-    # For meta path based loader, iter_modules and Python3 "__name__" to
-    # "__package__" parsing
-    result.append(".")
-
-    if python_version >= 300:
-        # Modules have that attribute starting with 3.3
-        result.append("__loader__")
-
-    if python_version >= 340:
-        result.append(
-            # YIELD_FROM uses this starting 3.4, with 3.3 other code is used.
-            "send"
-        )
-
-    if python_version >= 300:
-        result += (
-            # YIELD_FROM uses this
-            "throw",
-            "close",
-        )
-
-    if python_version < 300:
-        # For patching Python2 internal class type
-        result += ("__getattr__", "__setattr__", "__delattr__")
-
-        # For patching Python2 "sys" attributes for current exception
-        result += ("exc_type", "exc_value", "exc_traceback")
-
-    # The xrange built-in is Python2 only.
-    if python_version < 300:
-        result.append("xrange")
-
-    # Executables only
-    if not Options.shallMakeModule():
-        result.append("__main__")
-
-        # The "site" module is referenced in inspect patching.
-        result.append("site")
-
-    # Built-in original values
-    if not Options.shallMakeModule():
-        result += ["type", "len", "range", "repr", "int", "iter"]
-
-        if python_version < 300:
-            result.append("long")
-
-    if python_version >= 340:
-        # Setting the __spec__ module attribute.
-        result += ["__spec__", "_initializing", "submodule_search_locations"]
-
-    if python_version >= 350:
-        # Patching the types module.
-        result.append("types")
-
-    if not Options.shallMakeModule():
-        result += [sys.executable, sys.prefix]
-
-    if python_version >= 370:
-        result.append("__class_getitem__")
-
-    return result
-
-
-class PythonGlobalContext(object):
-    def __init__(self):
-        self.constants = {}
-        self.constant_use_count = {}
-
-        for constant in _getConstantDefaultPopulation():
-            code = self.getConstantCode(constant)
-
-            # Force them to be global.
-            self.countConstantUse(code)
-            self.countConstantUse(code)
-
-    def getConstantCode(self, constant):
-        # Use in user code, or for constants building code itself, many
-        # constant types get special code immediately.
-        # pylint: disable=too-many-branches
-        if constant is None:
-            key = "Py_None"
-        elif constant is True:
-            key = "Py_True"
-        elif constant is False:
-            key = "Py_False"
-        elif constant is Ellipsis:
-            key = "Py_Ellipsis"
-        elif constant is NotImplemented:
-            key = "Py_NotImplemented"
-        elif type(constant) is type:
-            # TODO: Maybe make this a mapping in nuitka.Builtins
-
-            if constant is None:
-                key = "(PyObject *)Py_TYPE( Py_None )"
-            elif constant is object:
-                key = "(PyObject *)&PyBaseObject_Type"
-            elif constant is staticmethod:
-                key = "(PyObject *)&PyStaticMethod_Type"
-            elif constant is classmethod:
-                key = "(PyObject *)&PyClassMethod_Type"
-            elif constant is bytearray:
-                key = "(PyObject *)&PyByteArray_Type"
-            elif constant is enumerate:
-                key = "(PyObject *)&PyEnum_Type"
-            elif constant is frozenset:
-                key = "(PyObject *)&PyFrozenSet_Type"
-            elif python_version >= 270 and constant is memoryview:
-                key = "(PyObject *)&PyMemoryView_Type"
-            elif (
-                python_version < 300
-                and constant is basestring  # pylint: disable=I0021,undefined-variable
-            ):
-                key = "(PyObject *)&PyBaseString_Type"
-            elif (
-                python_version < 300
-                and constant is xrange  # pylint: disable=I0021,undefined-variable
-            ):
-                key = "(PyObject *)&PyRange_Type"
-            elif constant in builtin_anon_values:
-                key = "(PyObject *)" + builtin_anon_codes[builtin_anon_values[constant]]
-            elif constant in builtin_exception_values_list:
-                key = "(PyObject *)PyExc_%s" % constant.__name__
-            else:
-                type_name = constant.__name__
-
-                if constant is int and python_version >= 300:
-                    type_name = "long"
-                elif constant is str:
-                    type_name = "string" if python_version < 300 else "unicode"
-
-                key = "(PyObject *)&Py%s_Type" % type_name.title()
-        else:
-            key = "const_" + namifyConstant(constant)
-
-        if key not in self.constants:
-            self.constants[key] = constant
-
-        return key
-
-    def countConstantUse(self, constant):
-        if constant not in self.constant_use_count:
-            self.constant_use_count[constant] = 0
-
-        self.constant_use_count[constant] += 1
-
-    def getConstantUseCount(self, constant):
-        return self.constant_use_count[constant]
-
-    def getConstants(self):
-        return self.constants
+    def addFunctionCreationInfo(self, creation_info):
+        return self.parent.addFunctionCreationInfo(creation_info)
 
 
 class FrameDeclarationsMixin(object):
@@ -979,7 +754,7 @@ class PythonModuleContext(
     # Plenty of attributes, because it's storing so many different things.
     # pylint: disable=too-many-instance-attributes
 
-    def __init__(self, module, module_name, code_name, filename, global_context):
+    def __init__(self, module, data_filename):
         PythonContextBase.__init__(self)
 
         TempMixin.__init__(self)
@@ -991,25 +766,24 @@ class PythonModuleContext(
         ReturnValueNameMixin.__init__(self)
 
         self.module = module
-        self.name = module_name
-        self.code_name = code_name
-        self.filename = filename
-
-        self.global_context = global_context
+        self.name = module.getFullName()
+        self.code_name = module.getCodeName()
 
         self.declaration_codes = {}
         self.helper_codes = {}
 
-        self.constants = set()
-
         self.frame_handle = None
 
-        self.needs_module_filename_object = False
-
         self.variable_storage = VariableStorage(heap_name=None)
 
+        self.function_table_entries = []
+
+        self.constant_accessor = ConstantAccessor(
+            top_level_name="mod_consts", data_filename=data_filename
+        )
+
     def __repr__(self):
-        return "<PythonModuleContext instance for module %s>" % self.filename
+        return "<PythonModuleContext instance for module %s>" % self.name
 
     def getOwner(self):
         return self.module
@@ -1023,9 +797,6 @@ class PythonModuleContext(
     def getName(self):
         return self.name
 
-    def getFilename(self):
-        return self.filename
-
     def mayRaiseException(self):
         body = self.module.getBody()
 
@@ -1062,23 +833,21 @@ class PythonModuleContext(
         return False
 
     def getConstantCode(self, constant):
-        result = self.global_context.getConstantCode(constant)
+        return self.constant_accessor.getConstantCode(constant)
 
-        if result not in self.constants:
-            self.constants.add(result)
-            self.global_context.countConstantUse(result)
+    def getConstantsCount(self):
+        return self.constant_accessor.getConstantsCount()
 
+    def addFunctionCreationInfo(self, creation_info):
+        self.function_table_entries.append(creation_info)
+
+    def getFunctionCreationInfos(self):
+        result = self.function_table_entries
+
+        # Release the memory once possible.
+        del self.function_table_entries
         return result
 
-    def getConstants(self):
-        return self.constants
-
-    def markAsNeedsModuleFilenameObject(self):
-        self.needs_module_filename_object = True
-
-    def needsModuleFilenameObject(self):
-        return self.needs_module_filename_object
-
 
 class PythonFunctionContext(
     FrameDeclarationsMixin,
@@ -1135,9 +904,6 @@ class PythonFunctionDirectContext(PythonFunctionContext):
     def isForDirectCall(self):
         return True
 
-    def isForCrossModuleUsage(self):
-        return self.function.isCrossModuleUsed()
-
     def isForCreatedFunction(self):
         return False
 
@@ -1149,9 +915,6 @@ class PythonGeneratorObjectContext(PythonFunctionContext):
     def isForDirectCall(self):
         return False
 
-    def isForCrossModuleUsage(self):
-        return self.function.isCrossModuleUsed()
-
     def isForCreatedFunction(self):
         return False
 
@@ -1296,9 +1059,8 @@ class PythonFunctionOutlineContext(
         return self.parent.isForDirectCall()
 
     def mayRecurse(self):
-        # TODO: In modules, there could be loops with outlines, we could detect
-        # that.
-        return True
+        # The outline is only accessible via its parent.
+        return self.parent.mayRecurse()
 
     def addLocalsDictName(self, locals_dict_name):
         return self.parent.addLocalsDictName(locals_dict_name)
