@@ -27,9 +27,11 @@ it being used.
 """
 
 import os
+import shutil
 import sys
 
 from nuitka import Options, OutputDirectories
+from nuitka.Errors import NuitkaPluginError
 from nuitka.ModuleRegistry import addUsedModule
 from nuitka.SourceCodeReferences import fromFilename
 from nuitka.Tracing import plugins_logger
@@ -43,7 +45,7 @@ warned_unused_plugins = set()
 
 
 class NuitkaPluginBase(object):
-    """ Nuitka base class for all plug-ins.
+    """Nuitka base class for all plug-ins.
 
     Derive your plugin from "NuitkaPluginBase" please.
     For instructions, see https://github.com/Nuitka/Nuitka/blob/orsiris/UserPlugin-Creation.rst
@@ -81,7 +83,7 @@ class NuitkaPluginBase(object):
 
     @staticmethod
     def isAlwaysEnabled():
-        """ Request to be always enabled.
+        """Request to be always enabled.
 
         Notes:
             Setting this to true is only applicable to standard plugins. In
@@ -97,7 +99,7 @@ class NuitkaPluginBase(object):
 
     @classmethod
     def isRelevant(cls):
-        """ Consider if the plugin is relevant.
+        """Consider if the plugin is relevant.
 
         Notes:
             A plugin may only be a needed on a certain OS, or with some options,
@@ -117,10 +119,10 @@ class NuitkaPluginBase(object):
 
     @classmethod
     def getPluginDefaultOptionValues(cls):
-        """ This method is used to get a values to use as defaults.
+        """This method is used to get a values to use as defaults.
 
-            Since the defaults are in the command line options, we call
-            that and extract them.
+        Since the defaults are in the command line options, we call
+        that and extract them.
         """
 
         from optparse import OptionGroup, OptionParser
@@ -136,7 +138,7 @@ class NuitkaPluginBase(object):
         return result
 
     def considerImplicitImports(self, module, signal_change):
-        """ Provide additional modules to import implicitly when encountering the module.
+        """Provide additional modules to import implicitly when encountering the module.
 
         Notes:
             Better do not overload this method.
@@ -151,12 +153,12 @@ class NuitkaPluginBase(object):
         """
         from nuitka.importing.Importing import getModuleNameAndKindFromFilename
 
-        for item in self.getImplicitImports(module):
-            # TODO: Temporary, until all plugins are caught up, turn into an error later.
-            if type(item) in (tuple, list):
-                full_name, _required = item
-            else:
-                full_name = item
+        for full_name in self.getImplicitImports(module):
+            if type(full_name) in (tuple, list):
+                raise NuitkaPluginError(
+                    "Plugin %s needs to be change to only return modules names, not %r"
+                    % (self, full_name)
+                )
 
             full_name = ModuleName(full_name)
 
@@ -193,7 +195,7 @@ class NuitkaPluginBase(object):
                 )
 
     def isRequiredImplicitImport(self, module, full_name):
-        """ Indicate whether an implicitly imported module should be accepted.
+        """Indicate whether an implicitly imported module should be accepted.
 
         Notes:
             You may negate importing a module specified as "implicit import",
@@ -209,7 +211,7 @@ class NuitkaPluginBase(object):
         return True
 
     def getImplicitImports(self, module):
-        """ Return the implicit imports for a given module (iterator).
+        """Return the implicit imports for a given module (iterator).
 
         Args:
             module: the module object
@@ -223,7 +225,7 @@ class NuitkaPluginBase(object):
     module_aliases = {}
 
     def considerFailedImportReferrals(self, module_name):
-        """ Provide a dictionary of fallback imports for modules that failed to import.
+        """Provide a dictionary of fallback imports for modules that failed to import.
 
         Args:
             module_name: name of module
@@ -233,7 +235,7 @@ class NuitkaPluginBase(object):
         return self.module_aliases.get(module_name, None)
 
     def onModuleSourceCode(self, module_name, source_code):
-        """ Inspect or modify source code.
+        """Inspect or modify source code.
 
         Args:
             module_name: (str) name of module
@@ -250,7 +252,7 @@ class NuitkaPluginBase(object):
         return source_code
 
     def checkModuleSourceCode(self, module_name, source_code):
-        """ Inspect source code.
+        """Inspect source code.
 
         Args:
             module_name: (str) name of module
@@ -260,7 +262,7 @@ class NuitkaPluginBase(object):
         """
 
     def onFrozenModuleSourceCode(self, module_name, is_package, source_code):
-        """ Inspect or modify frozen module source code.
+        """Inspect or modify frozen module source code.
 
         Args:
             module_name: (str) full name of module
@@ -273,7 +275,7 @@ class NuitkaPluginBase(object):
         return source_code
 
     def onFrozenModuleBytecode(self, module_name, is_package, bytecode):
-        """ Inspect or modify frozen module byte code.
+        """Inspect or modify frozen module byte code.
 
         Args:
             module_name: (str) name of module
@@ -287,7 +289,7 @@ class NuitkaPluginBase(object):
 
     @staticmethod
     def _createTriggerLoadedModule(module, trigger_name, code):
-        """ Create a "trigger" for a module to be imported.
+        """Create a "trigger" for a module to be imported.
 
         Notes:
             The trigger will incorpaorate the code to be prepended / appended.
@@ -301,8 +303,9 @@ class NuitkaPluginBase(object):
         Returns
             trigger_module
         """
-        from nuitka.tree.Building import createModuleTree
         from nuitka.nodes.ModuleNodes import CompiledPythonModule
+        from nuitka.tree.Building import createModuleTree
+
         from .Plugins import Plugins
 
         module_name = ModuleName(module.getFullName() + trigger_name)
@@ -340,7 +343,7 @@ class NuitkaPluginBase(object):
 
     @staticmethod
     def createPreModuleLoadCode(module):
-        """ Create code to prepend to a module.
+        """Create code to prepend to a module.
 
         Notes:
             Called by @onModuleDiscovered.
@@ -355,7 +358,7 @@ class NuitkaPluginBase(object):
 
     @staticmethod
     def createPostModuleLoadCode(module):
-        """ Create code to append to a module.
+        """Create code to append to a module.
 
         Notes:
             Called by @onModuleDiscovered.
@@ -369,7 +372,7 @@ class NuitkaPluginBase(object):
         return None, None
 
     def onModuleDiscovered(self, module):
-        """ Called with a module to be loaded.
+        """Called with a module to be loaded.
 
         Notes:
             We may specify code to be prepended and/or appended to this module.
@@ -391,11 +394,9 @@ class NuitkaPluginBase(object):
             if full_name in pre_modules:
                 sys.exit("Error, conflicting plug-ins for %s" % full_name)
 
-            plugins_logger.info(
-                "Injecting plug-in based pre load code for module '%s':" % full_name
-            )
+            self.info("Injecting pre-module load code for module '%s':" % full_name)
             for line in reason.split("\n"):
-                plugins_logger.info("    " + line)
+                self.info("    " + line)
 
             pre_modules[full_name] = self._createTriggerLoadedModule(
                 module=module, trigger_name="-preLoad", code=pre_code
@@ -408,18 +409,16 @@ class NuitkaPluginBase(object):
             if full_name is post_modules:
                 sys.exit("Error, conflicting plug-ins for %s" % full_name)
 
-            plugins_logger.info(
-                "Injecting plug-in based post load code for module '%s':" % full_name
-            )
+            self.info("Injecting post-module load code for module '%s':" % full_name)
             for line in reason.split("\n"):
-                plugins_logger.info("    " + line)
+                self.info("    " + line)
 
             post_modules[full_name] = self._createTriggerLoadedModule(
                 module=module, trigger_name="-postLoad", code=post_code
             )
 
     def onModuleEncounter(self, module_filename, module_name, module_kind):
-        """ Help decide whether to include a module.
+        """Help decide whether to include a module.
 
         Args:
             module_filename: filename
@@ -433,7 +432,7 @@ class NuitkaPluginBase(object):
 
     @staticmethod
     def locateModule(importing, module_name):
-        """ Provide a filename / -path for a to-be-imported module.
+        """Provide a filename / -path for a to-be-imported module.
 
         Args:
             importing: module object
@@ -456,7 +455,7 @@ class NuitkaPluginBase(object):
 
     @staticmethod
     def decideRecursion(module_filename, module_name, module_kind):
-        """ Decide whether Nuitka should recurse down to a given module.
+        """Decide whether Nuitka should recurse down to a given module.
 
         Args:
             module_filename: filename
@@ -495,7 +494,7 @@ class NuitkaPluginBase(object):
             )
 
     def considerExtraDlls(self, dist_dir, module):
-        """ Provide a tuple of names of binaries to be included.
+        """Provide a tuple of names of binaries to be included.
 
         Args:
             dist_dir: the distribution folder
@@ -503,11 +502,29 @@ class NuitkaPluginBase(object):
         Returns:
             tuple
         """
+        # TODO: This should no longer be here, as this API is obsolete, pylint: disable=unused-argument
+
+        for included_entry_point in self.getExtraDlls(module):
+            # Copy to the dist directory.
+            target_path = (included_entry_point.dest_path,)
+            shutil.copyfile(included_entry_point.source_path, target_path)
+
+            yield included_entry_point
+
+    def getExtraDlls(self, module):
+        """Provide IncludedEntryPoint named tuples describing extra needs of the module.
+
+        Args:
+            module: the module object needing the binaries
+        Returns:
+            yields IncludedEntryPoint objects
+
+        """
         # Virtual method, pylint: disable=no-self-use,unused-argument
         return ()
 
     def removeDllDependencies(self, dll_filename, dll_filenames):
-        """ Yield any DLLs / shared libraries not to be included in distribution.
+        """Yield any DLLs / shared libraries not to be included in distribution.
 
         Args:
             dll_filename: DLL name
@@ -519,7 +536,7 @@ class NuitkaPluginBase(object):
         return ()
 
     def considerDataFiles(self, module):
-        """ Yield data file names (source|func, target) for inclusion (iterator).
+        """Yield data file names (source|func, target) for inclusion (iterator).
 
         Args:
             module: module object that may need extra data files
@@ -532,7 +549,7 @@ class NuitkaPluginBase(object):
         return ()
 
     def onStandaloneDistributionFinished(self, dist_dir):
-        """ Called after successfully finishing a standalone compile.
+        """Called after successfully finishing a standalone compile.
 
         Note:
             It is up to the plugin to take subsequent action. Examples are:
@@ -550,7 +567,7 @@ class NuitkaPluginBase(object):
         return None
 
     def suppressUnknownImportWarning(self, importing, module_name, source_ref):
-        """ Suppress import warnings for unknown modules.
+        """Suppress import warnings for unknown modules.
 
         Args:
             importing: the module object
@@ -563,7 +580,7 @@ class NuitkaPluginBase(object):
         return False
 
     def decideCompilation(self, module_name, source_ref):
-        """ Decide whether to compile a module (or just use its bytecode).
+        """Decide whether to compile a module (or just use its bytecode).
 
         Notes:
             The first plugin not returning None makes the decision. Thereafter,
@@ -581,7 +598,7 @@ class NuitkaPluginBase(object):
         return None
 
     def getPreprocessorSymbols(self):
-        """ Decide which C defines to be used in compilation.
+        """Decide which C defines to be used in compilation.
 
         Notes:
             The plugins can each contribute, but are hopefully using
@@ -596,7 +613,7 @@ class NuitkaPluginBase(object):
         return None
 
     def getExtraCodeFiles(self):
-        """ Add extra code files to the compilation.
+        """Add extra code files to the compilation.
 
         Notes:
             This is generally a bad idea to use unless you absolutely
@@ -611,7 +628,7 @@ class NuitkaPluginBase(object):
         return None
 
     def getExtraLinkLibraries(self):
-        """ Decide which link library should be added.
+        """Decide which link library should be added.
 
         Notes:
             Names provided multiple times, e.g. by multiple plugins are
@@ -626,7 +643,7 @@ class NuitkaPluginBase(object):
         return None
 
     def warnUnusedPlugin(self, message):
-        """ An inactive plugin may issue a warning if it believes this may be wrong.
+        """An inactive plugin may issue a warning if it believes this may be wrong.
 
         Returns:
             None
