@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -22,21 +22,20 @@ know the variables written by a piece of code ahead of abstractly executing a
 loop.
 """
 
+from nuitka.containers.oset import OrderedSet
+
 from .Operations import VisitorNoopMixin, visitTree
 
-class VariableWriteExtractor(VisitorNoopMixin):
-    """ Extract variables written to.
 
-    """
+class VariableWriteExtractor(VisitorNoopMixin):
+    """Extract variables written to."""
+
     def __init__(self):
-        self.written_to = set()
+        self.written_to = OrderedSet()
 
     def onEnterNode(self, node):
-        if node.isExpressionTargetVariableRef() or \
-           node.isExpressionAssignmentTempKeeper():
-            key = node.getVariable(), node.getVariableVersion()
-
-            self.written_to.add( key )
+        if node.isStatementAssignmentVariable() or node.isStatementDelVariable():
+            self.written_to.add(node.getVariable())
 
     def getResult(self):
         return self.written_to
@@ -44,6 +43,27 @@ class VariableWriteExtractor(VisitorNoopMixin):
 
 def getVariablesWritten(node):
     visitor = VariableWriteExtractor()
-    visitTree( node, visitor )
+    visitTree(node, visitor)
 
     return visitor.getResult()
+
+
+class VariableUsageUpdater(VisitorNoopMixin):
+    def __init__(self, old_variable, new_variable):
+        self.old_variable = old_variable
+        self.new_variable = new_variable
+
+    def onEnterNode(self, node):
+        if (
+            node.isStatementAssignmentVariable()
+            or node.isStatementDelVariable()
+            or node.isStatementReleaseVariable()
+        ):
+            if node.getVariable() is self.old_variable:
+                node.setVariable(self.new_variable)
+
+
+def updateVariableUsage(provider, old_variable, new_variable):
+    visitor = VariableUsageUpdater(old_variable=old_variable, new_variable=new_variable)
+
+    visitTree(provider, visitor)
