@@ -100,14 +100,16 @@ def checkRequirements(filename):
 def displayError(dirname, filename):
     assert dirname is None
 
-    my_print("Listing of dist folder:")
+    filename = filename[:-3] + ".dist"
+
+    my_print("Listing of dist folder '%s':" % filename)
 
     if os.name == "nt":
-        command = "dir /b /s /a:-D %s"
+        command = "dir /b /s /a:-D %s" % filename
     else:
-        command = "ls -Rla %s"
+        command = "ls -Rla %s" % filename
 
-    os.system(command % filename)
+    os.system(command)
 
 
 def main():
@@ -131,13 +133,7 @@ def main():
             my_print("Skipping", filename)
             continue
 
-        extra_flags = [
-            "expect_success",
-            "standalone",
-            "remove_output",
-            # For enum plugin info
-            "ignore_infos",
-        ]
+        extra_flags = ["expect_success", "standalone", "remove_output"]
 
         # skip each test if their respective requirements are not met
         requirements_met, error_message = checkRequirements(filename)
@@ -611,8 +607,16 @@ def main():
                 my_print("Listing of dist folder:")
                 os.system("ls -Rla %s" % filename[:-3] + ".dist")
 
-                my_print("strace:")
-                os.system("strace -s4096 -e file %s" % binary_filename)
+                my_print("Inclusion log:")
+                os.system("cat %s" % filename[:-3] + ".py.inclusion.log")
+
+                # Run with traces to help debugging, specifically in CI environment.
+                if sys.platform == "darwin" or sys.platform.startswith("freebsd"):
+                    my_print("dtruss:")
+                    os.system("sudo dtruss %s" % binary_filename)
+                else:
+                    my_print("strace:")
+                    os.system("strace -s4096 -e file %s" % binary_filename)
 
             search_mode.onErrorDetected(1)
 
